@@ -57,10 +57,7 @@ class LoadOverlayAction(base.Action):
         :arg displayCtx:  The :class:`.DisplayContext`.
         :arg frame:       The :class:`.FSLeyesFrame`.
         """
-        base.Action.__init__(self, self.__loadOverlay)
-
-        self.__overlayList = overlayList
-        self.__displayCtx  = displayCtx
+        base.Action.__init__(self, overlayList, displayCtx, self.__loadOverlay)
 
 
     def __loadOverlay(self):
@@ -79,19 +76,18 @@ class LoadOverlayAction(base.Action):
             if len(overlays) == 0:
                 return
 
-            self.__overlayList.extend(overlays)
+            self.overlayList.extend(overlays)
 
-            self.__displayCtx.selectedOverlay = \
-                self.__displayCtx.overlayOrder[-1]
+            self.displayCtx.selectedOverlay = self.displayCtx.overlayOrder[-1]
 
-            if self.__displayCtx.autoDisplay:
+            if self.displayCtx.autoDisplay:
                 for overlay in overlays:
                     autodisplay.autoDisplay(overlay,
-                                            self.__overlayList,
-                                            self.__displayCtx)
+                                            self.overlayList,
+                                            self.displayCtx)
 
         interactiveLoadOverlays(onLoad=onLoad,
-                                inmem=self.__displayCtx.loadInMemory)
+                                inmem=self.displayCtx.loadInMemory)
 
 
 def makeWildcard(allowedExts=None, descs=None):
@@ -290,9 +286,8 @@ def loadImage(dtype, path, inmem=False):
     from the whole image, or from a sample.
 
     This function returns a sequence, most likely containing a single
-    :class:`.Image` instance. But in some circumstances (e.g. image files with
-    a complex data type), more than one :class:`.Image` will be created and
-    returned.
+    :class:`.Image` instance. But in some circumstances, more than one
+    :class:`.Image` will be created and returned.
 
     :arg dtype: Overlay type (``Image``, or a sub-class of ``Image``).
     :arg path:  Path to the overlay file.
@@ -321,19 +316,13 @@ def loadImage(dtype, path, inmem=False):
                   calcRange=False,
                   threaded=False)
 
-    imgdtype = image.dtype
-    nbytes   = np.prod(image.shape) * image.dtype.itemsize
-    image    = None
+    nbytes = np.prod(image.shape) * image.dtype.itemsize
+    image  = None
 
-    # Complex images are split into two separate overlays
-    if (dtype is fslimage.Image) and \
-       np.issubdtype(imgdtype, np.complexfloating):
-        return _loadComplexImage(path)
-    else:
-        return [_loadNonComplexImage(dtype, path, nbytes, inmem)]
+    return [_loadImage(dtype, path, nbytes, inmem)]
 
 
-def _loadNonComplexImage(dtype, path, nbytes, inmem):
+def _loadImage(dtype, path, nbytes, inmem):
     """Loads an image with a non-complex data type.
 
     :arg dtype:  Overlay type - :class:`.Image`, or a sub-class of ``Image``.
@@ -378,31 +367,6 @@ def _loadNonComplexImage(dtype, path, nbytes, inmem):
     return image
 
 
-def _loadComplexImage(path):
-    """Loads the specified ``path`` assumed to be a NIFTI image
-    with complex data.
-
-    The image is loaded as two separate :class:`.Image` instances,
-    containing the real and imaginary components respectively.
-    """
-
-    import nibabel        as nib
-    import fsl.data.image as fslimage
-
-    image = nib.load(path)
-    hdr   = image.header
-    data  = image.get_data()
-
-    name  = op.basename(fslimage.removeExt(path))
-    rname = '{} [real]'.format(name)
-    iname = '{} [imag]'.format(name)
-
-    real = fslimage.Image(np.real(data), name=rname, header=hdr)
-    imag = fslimage.Image(np.imag(data), name=iname, header=hdr)
-
-    return real, imag
-
-
 def interactiveLoadOverlays(fromDir=None, dirdlg=False, **kwargs):
     """Convenience function for interactively loading one or more overlays.
 
