@@ -170,6 +170,10 @@ def _initPropertyList_VolumeOpts(threedee):
     return plist
 
 
+def _initPropertyList_ComplexOpts(threedee):
+    return ['component']
+
+
 def _init3DPropertyList_VolumeOpts():
     return ['blendFactor',
             'numSteps',
@@ -443,6 +447,14 @@ def _init3DWidgetSpec_VolumeOpts():
     }
 
 
+def _initWidgetSpec_ComplexOpts(threedee):
+    return {
+        'component' : props.Widget(
+            'component',
+            labels=strings.choices['ComplexOpts.component'])
+    }
+
+
 def _initWidgetSpec_MaskOpts(threedee):
     return {
         'custom_volume'  : _NiftiOpts_VolumeWidget,
